export enum Clue {
    Absent,
    Elsewhere,
    Correct,
}

export interface CluedLetter {
    clue?: Clue;
    letter: string;
}


export type GuessResult = {
    word: string;
    matches: number[];
};

export function clue(result: GuessResult): CluedLetter[] {
    return result.word.split("").map((letter, i) => {
        const match = result.matches[i];
        return {
            clue: match === 0 ? Clue.Absent : (match === 1 ? Clue.Elsewhere : (match === 2 ? Clue.Correct : Clue.Absent)),
            letter: letter,
        };
    });
}

export function clueClass(clue: Clue): string {
    if (clue === Clue.Absent) {
        return "letter-absent";
    } else if (clue === Clue.Elsewhere) {
        return "letter-elsewhere";
    } else {
        return "letter-correct";
    }
}

export function clueWord(clue: Clue): string {
    if (clue === Clue.Absent) {
        return "no";
    } else if (clue === Clue.Elsewhere) {
        return "elsewhere";
    } else {
        return "correct";
    }
}

export function describeClue(clue: CluedLetter[]): string {
    return clue
        .map(({ letter, clue }) => letter.toUpperCase() + " " + clueWord(clue!))
        .join(", ");
}
